@@ -9,6 +9,7 @@ class ColumnSpecWrapper:
     This wrapper provides a nicely formatted string for column spec
 
     """
+
     def __init__(self, column_spec: Column) -> None:
         self.column_spec: Column = column_spec
         self.column_spec_formatted: str = self.to_debug_string()
@@ -29,14 +30,14 @@ class ColumnSpecWrapper:
         """
         output: str = ""
         txt: str = str(self.column_spec)
-        items: List[str] = re.split(r'([()])', txt)
+        items: List[str] = re.split(r"([()])", txt)
         indent: int = 0
         item: str
         for item in items:
             if item != "":
                 if item == ")":
                     indent -= 1
-                output += "\n" + ('\t' * indent)
+                output += "\n" + ("\t" * indent)
                 output += f"{item}"
                 if item == "(":
                     indent += 1
