@@ -2,6 +2,7 @@ from typing import Dict
 
 from pyspark.sql import SparkSession, Column, DataFrame
 from pyspark.sql.functions import coalesce
+
 # noinspection PyUnresolvedReferences
 from pyspark.sql.functions import lit, col
 from pyspark.sql.types import StringType
@@ -14,10 +15,11 @@ def test_auto_mapper_coalesce(spark_session: SparkSession) -> None:
     # Arrange
     spark_session.createDataFrame(
         [
-            (1, 'Qureshi', 'Imran', None),
-            (2, None, 'Michael', "1970-02-02"),
-            (3, None, 'Michael', None),
-        ], ['member_id', 'last_name', 'first_name', "date_of_birth"]
+            (1, "Qureshi", "Imran", None),
+            (2, None, "Michael", "1970-02-02"),
+            (3, None, "Michael", None),
+        ],
+        ["member_id", "last_name", "first_name", "date_of_birth"],
     ).createOrReplaceTempView("patients")
 
     source_df: DataFrame = spark_session.table("patients")
@@ -30,22 +32,20 @@ def test_auto_mapper_coalesce(spark_session: SparkSession) -> None:
         view="members", source_view="patients", keys=["member_id"]
     ).columns(
         my_column=A.coalesce(
-            A.column("last_name"), A.column("date_of_birth"),
-            A.text("last_resort")
+            A.column("last_name"), A.column("date_of_birth"), A.text("last_resort")
         )
     )
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs(
-        source_df=source_df
-    )
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
     assert str(sql_expressions["my_column"]) == str(
         coalesce(
-            col("b.last_name"), col("b.date_of_birth"),
-            lit("last_resort").cast(StringType())
+            col("b.last_name"),
+            col("b.date_of_birth"),
+            lit("last_resort").cast(StringType()),
         ).alias("my_column")
     )
 
@@ -55,9 +55,15 @@ def test_auto_mapper_coalesce(spark_session: SparkSession) -> None:
     result_df.printSchema()
     result_df.show()
 
-    assert result_df.where("member_id == 1"
-                           ).select("my_column").collect()[0][0] == "Qureshi"
-    assert result_df.where("member_id == 2").select("my_column").collect(
-    )[0][0] == "1970-02-02"
-    assert result_df.where("member_id == 3").select("my_column").collect(
-    )[0][0] == "last_resort"
+    assert (
+        result_df.where("member_id == 1").select("my_column").collect()[0][0]
+        == "Qureshi"
+    )
+    assert (
+        result_df.where("member_id == 2").select("my_column").collect()[0][0]
+        == "1970-02-02"
+    )
+    assert (
+        result_df.where("member_id == 3").select("my_column").collect()[0][0]
+        == "last_resort"
+    )
