@@ -1,12 +1,15 @@
 from typing import Dict, Optional, Union
 
 from pyspark.sql import SparkSession, Column, DataFrame
+
 # noinspection PyUnresolvedReferences
 from pyspark.sql.functions import col, when, lit
 from pyspark.sql.types import StructType, StructField, StringType, LongType, DataType
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
-from spark_auto_mapper.data_types.complex.complex_base import AutoMapperDataTypeComplexBase
+from spark_auto_mapper.data_types.complex.complex_base import (
+    AutoMapperDataTypeComplexBase,
+)
 from spark_auto_mapper.data_types.number import AutoMapperNumberDataType
 from spark_auto_mapper.data_types.text_like_base import AutoMapperTextLikeBase
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
@@ -14,8 +17,10 @@ from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 class MyClass(AutoMapperDataTypeComplexBase):
     def __init__(
-        self, id_: AutoMapperTextLikeBase, name: AutoMapperTextLikeBase,
-        age: AutoMapperNumberDataType
+        self,
+        id_: AutoMapperTextLikeBase,
+        name: AutoMapperTextLikeBase,
+        age: AutoMapperNumberDataType,
     ) -> None:
         super().__init__(id_=id_, name=name, age=age)
 
@@ -32,15 +37,14 @@ class MyClass(AutoMapperDataTypeComplexBase):
         return schema
 
 
-def test_automapper_complex_with_skip_if_null(
-    spark_session: SparkSession
-) -> None:
+def test_automapper_complex_with_skip_if_null(spark_session: SparkSession) -> None:
     # Arrange
     spark_session.createDataFrame(
         [
-            (1, 'Qureshi', 'Imran', 45),
-            (2, 'Vidal', '', 35),
-        ], ['member_id', 'last_name', 'first_name', 'my_age']
+            (1, "Qureshi", "Imran", 45),
+            (2, "Vidal", "", 35),
+        ],
+        ["member_id", "last_name", "first_name", "my_age"],
     ).createOrReplaceTempView("patients")
 
     source_df: DataFrame = spark_session.table("patients")
@@ -54,19 +58,17 @@ def test_automapper_complex_with_skip_if_null(
         source_view="patients",
         keys=["member_id"],
         drop_key_columns=True,
-        skip_if_columns_null_or_empty=["first_name"]
+        skip_if_columns_null_or_empty=["first_name"],
     ).complex(
         MyClass(
             id_=A.column("member_id"),
             name=A.column("last_name"),
-            age=A.number(A.column("my_age"))
+            age=A.number(A.column("my_age")),
         )
     )
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs(
-        source_df=source_df
-    )
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
@@ -75,15 +77,19 @@ def test_automapper_complex_with_skip_if_null(
     # Assert
     assert str(sql_expressions["name"]) == str(
         when(
-            col("b.first_name").isNull() | col("b.first_name").eqNullSafe(""),
-            lit(None)
-        ).otherwise(col("b.last_name")).cast(StringType()).alias("name")
+            col("b.first_name").isNull() | col("b.first_name").eqNullSafe(""), lit(None)
+        )
+        .otherwise(col("b.last_name"))
+        .cast(StringType())
+        .alias("name")
     )
     assert str(sql_expressions["age"]) == str(
         when(
-            col("b.first_name").isNull() | col("b.first_name").eqNullSafe(""),
-            lit(None)
-        ).otherwise(col("b.my_age")).cast(LongType()).alias("age")
+            col("b.first_name").isNull() | col("b.first_name").eqNullSafe(""), lit(None)
+        )
+        .otherwise(col("b.my_age"))
+        .cast(LongType())
+        .alias("age")
     )
 
     result_df.printSchema()
@@ -91,7 +97,6 @@ def test_automapper_complex_with_skip_if_null(
     result_df.show()
 
     assert result_df.count() == 1
-    assert result_df.where("id == 1").select("name"
-                                             ).collect()[0][0] == "Qureshi"
+    assert result_df.where("id == 1").select("name").collect()[0][0] == "Qureshi"
 
     assert dict(result_df.dtypes)["age"] in ("int", "long", "bigint")
