@@ -1,6 +1,7 @@
 from typing import Dict
 
 from pyspark.sql import SparkSession, Column, DataFrame
+
 # noinspection PyUnresolvedReferences
 from pyspark.sql.functions import col
 
@@ -12,9 +13,10 @@ def test_auto_mapper_with_column(spark_session: SparkSession) -> None:
     # Arrange
     spark_session.createDataFrame(
         [
-            (1, 'Qureshi', 'Imran'),
-            (2, 'Vidal', 'Michael'),
-        ], ['member_id', 'last_name', 'first_name']
+            (1, "Qureshi", "Imran"),
+            (2, "Vidal", "Michael"),
+        ],
+        ["member_id", "last_name", "first_name"],
     ).createOrReplaceTempView("patients")
 
     source_df: DataFrame = spark_session.table("patients")
@@ -28,14 +30,11 @@ def test_auto_mapper_with_column(spark_session: SparkSession) -> None:
     ).columns(lname=A.column("last_name"))
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs(
-        source_df=source_df
-    )
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["lname"]
-               ) == str(col("b.last_name").alias("lname"))
+    assert str(sql_expressions["lname"]) == str(col("b.last_name").alias("lname"))
 
     result_df: DataFrame = mapper.transform(df=df)
 
@@ -43,7 +42,7 @@ def test_auto_mapper_with_column(spark_session: SparkSession) -> None:
     result_df.printSchema()
     result_df.show()
 
-    assert result_df.where("member_id == 1"
-                           ).select("lname").collect()[0][0] == "Qureshi"
-    assert result_df.where("member_id == 2"
-                           ).select("lname").collect()[0][0] == "Vidal"
+    assert (
+        result_df.where("member_id == 1").select("lname").collect()[0][0] == "Qureshi"
+    )
+    assert result_df.where("member_id == 2").select("lname").collect()[0][0] == "Vidal"
